@@ -31,10 +31,10 @@ class Settings : public Lum::Dlg::ActionDialog
 {
 private:
   Lum::Model::ActionRef      okAction;
-  Lum::Model::SizeTRef       choice;
+  Lum::Model::ULongRef       choice;
   Lum::Model::StringTableRef choices;
-  Lum::Model::SizeTRef       setting;
-  Lum::Model::SizeTRef       preset;
+  Lum::Model::ULongRef       setting;
+  Lum::Model::ULongRef       preset;
   Lum::Model::StringTableRef presets;
   Lum::Model::StringRef      factor;
   Lum::Model::StringRef      unit;
